==> kubernetes-model-1.0.11-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NamedRoleBindingBuilder extends NamedRoleBindingFluent<NamedRoleBindingBuilder> implements VisitableBuilder<NamedRoleBinding,NamedRoleBindingBuilder>{

     NamedRoleBindingFluent<?> fluent;
public NamedRoleBindingBuilder(){
    this(new NamedRoleBinding());
}
public NamedRoleBindingBuilder( NamedRoleBindingFluent<?> fluent ){
    this(fluent, new NamedRoleBinding());
}
public NamedRoleBindingBuilder( NamedRoleBindingFluent<?> fluent , NamedRoleBinding instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRoleBinding(instance.getRoleBinding()); 
}
public NamedRoleBindingBuilder( NamedRoleBinding instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRoleBinding(instance.getRoleBinding()); 
}

public EditableNamedRoleBinding build(){
    EditableNamedRoleBinding buildable = new EditableNamedRoleBinding(fluent.getName(),fluent.getRoleBinding());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedRoleBindingBuilder that = (NamedRoleBindingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/NamedRoleBindingBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NamedRoleBindingBuilder extends NamedRoleBindingFluentImpl<NamedRoleBindingBuilder> implements VisitableBuilder<NamedRoleBinding,NamedRoleBindingBuilder>{

     NamedRoleBindingFluent<?> fluent;
public NamedRoleBindingBuilder(){
    this(new NamedRoleBinding());
}
public NamedRoleBindingBuilder( NamedRoleBindingFluent<?> fluent ){
    this(fluent, new NamedRoleBinding());
}
public NamedRoleBindingBuilder( NamedRoleBindingFluent<?> fluent , NamedRoleBinding instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRoleBinding(instance.getRoleBinding()); 
}
public NamedRoleBindingBuilder( NamedRoleBinding instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRoleBinding(instance.getRoleBinding()); 
}

public NamedRoleBinding build(){
    NamedRoleBinding buildable = new NamedRoleBinding(fluent.getName(),fluent.getRoleBinding());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedRoleBindingBuilder that = (NamedRoleBindingBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
